@@ -28,6 +28,7 @@ const Mainloop = imports.mainloop;
 
 const Application = imports.application;
 const ExportViewDialog = imports.exportViewDialog;
+const GeocodeFactory = imports.geocode;
 const Location = imports.location;
 const OSMAccountDialog = imports.osmAccountDialog;
 const OSMEdit = imports.osmEdit;
@@ -120,11 +121,8 @@ var ContextMenu = GObject.registerClass({
     }
 
     _onWhatsHereActivated() {
-        let location = new Location.Location({ latitude: this._latitude,
-                                               longitude: this._longitude,
-                                               accuracy: 0 });
-
-        Application.geocodeService.reverse(location, null, (place) => {
+        GeocodeFactory.getGeocoder().reverse(this._latitude, this._longitude,
+                                      (place) => {
             if (place) {
                 this._mapView.showPlace(place, false);
             } else {
