@@ -147,13 +147,10 @@ class MapBubble extends Gtk.Popover {
                                                      modal: true,
                                                      mapView: this._mapView,
                                                      place: this._place });
-        if (!dialog.ensureApplications())
-            return;
-
         button.visible = true;
         button.connect('clicked', () => {
             dialog.connect('response', () => dialog.hide());
-            dialog.show_all();
+            dialog.show();
         });
     }
 
