@@ -336,8 +336,9 @@ var MapView = GObject.registerClass({
         } else {
             let renderer = new Champlain.ImageRenderer();
             let source = new Maps.FileTileSource({
-                path: Application.application.local_tile_path.toString(),
-                renderer: renderer
+                path: Utils.getBufferText(Application.application.local_tile_path),
+                renderer: renderer,
+                tile_size: 512
             });
             try {
                 source.prepare();
