@@ -19,10 +19,14 @@
  * Author: Jonas Danielsson <jonas@threetimestwo.org>
  */
 
+const _ = imports.gettext.gettext;
+
 const Geocode = imports.gi.GeocodeGlib;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
+
 const Location = imports.location;
+const Overpass = imports.overpass;
 const Translations = imports.translations;
 const Utils = imports.utils;
 
@@ -38,6 +42,14 @@ const DMS_COORDINATES_REGEX = new RegExp(
     "i"
 );
 
+// Matches a URL pointing to an object in OpenStreetMap
+const OSM_OBJECT_URL_REGEX =
+    new RegExp(/https?:\/\/(www\.)?openstreetmap\.org\/(node|way|relation)\/(\d+)\/?$/);
+
+// Matches a URL with a specifies coordinate in OpenStreetMap
+const OSM_COORD_URL_REGEX =
+    new RegExp(/https?:\/\/(www\.)?openstreetmap\.org\/?\?(\&?mlat=(\d+(?:\.\d+)?))?(\&mlon=(\d+(?:\.\d+)?))?(\&zoom=(\d+))?(\#map=(\d+)\/(\d+(?:\.\d+)?)\/(\d+(?:\.\d+)?))?/);
+
 var Place = GObject.registerClass(
 class Place extends Geocode.Place {
 
@@ -72,6 +84,16 @@ class Place extends Geocode.Place {
         this._note = params.note;
         delete params.note;
 
+        this._initialZoom = params.initialZoom;
+        delete params.initialZoom;
+
+        /* set to true if the instance is pre-filled with Overpass data,
+         * at the time of creation, as will be the case when loading a place
+         * from an OSM object URL
+         */
+        this._prefilled = params.prefilled;
+        delete params.prefilled;
+
         /* Determines if the place should be added to the place store */
         if (typeof(params.store) === 'undefined') {
             this._store = true;
@@ -226,6 +248,18 @@ class Place extends Geocode.Place {
         return this._translateWheelchair(this._wheelchair);
     }
 
+    get initialZoom() {
+        return this._initialZoom;
+    }
+
+    get prefilled() {
+        return this._prefilled;
+    }
+
+    set prefilled(prefilled) {
+        this._prefilled = prefilled;
+    }
+
     _translateWheelchair(string) {
         switch(string) {
             /* Translators:
@@ -412,3 +446,79 @@ Place.parseCoordinates = function(text) {
         return null;
     }
 };
+
+let overpass = null;
+
+/* we can't import Application before the Place class has been defined
+ * since it's used via PlaceStore
+ */
+const Application = imports.application;
+
+function _parseOSMObjectURL(match, callback) {
+    let [,, type, id] = match;
+    let storedPlace = Application.placeStore.existsWithOsmTypeAndId(type, id);
+
+    if (storedPlace) {
+        callback(storedPlace, null);
+        return;
+    }
+
+    if (overpass === null)
+        overpass = new Overpass.Overpass();
+
+    Application.application.mark_busy();
+    overpass.fetchPlace(type, id, (place) => {
+        Application.application.unmark_busy();
+        if (place)
+            callback(place, null);
+        else
+            callback(null, _("Place not found in OpenStreetMap"));
+    });
+}
+
+function _parseOSMCoordURL(match, callback) {
+    let [,,,mlat,,mlon,,zoom,,mapZoom,mapLat, mapLon] = match;
+    let lat;
+    let lon;
+    let z;
+
+    if (mapZoom && mapLat && mapLon) {
+        lat = mapLat;
+        lon = mapLon;
+        z = mapZoom;
+    } else if (mlat && mlon) {
+        lat = mlat;
+        lon = mlon;
+        if (zoom)
+            z = zoom;
+    } else {
+        callback(null, _("OpenStreetMap URL is not valid"));
+        return;
+    }
+
+    if (!Place.validateCoordinates(lat, lon)) {
+        callback(null, _("Coordinates in URL are not valid"));
+        return;
+    }
+
+    let location = new Location.Location({ latitude: lat, longitude: lon });
+    let place = z ? new Place({ location: location, initialZoom: z }) :
+                    new Place({ location: location });
+
+    callback(place, null);
+}
+
+function parseHttpURL(text, callback) {
+    let match = text.match(OSM_OBJECT_URL_REGEX);
+
+    if (match) {
+        _parseOSMObjectURL(match, callback);
+    } else {
+        match = text.match(OSM_COORD_URL_REGEX);
+        if (match)
+            _parseOSMCoordURL(match, callback);
+        else
+            callback(null, _("URL is not supported"));
+    }
+}
+
